Flask-arrest
============

Flask-arrest is a `Flask <http://flask.pocoo.org>`_-extension that works hard
to make it easy to implement `REST <http://wikipedia.org/wiki/REST>`_-APIs
using Flask.

See the `documentation <https://pythonhosted.org/Flask-arrest/>`_ for detailed
usage instructions.

Note that that large parts of the API have changed between version 0.3 and
0.4 (Flask-arrest is still experimental!).
